#!/bin/python
from flask import Flask, render_template, g
import mysql.connector
import sqlite3

app = Flask(__name__)
config = app.config
config.from_pyfile('config.py')

# Row wrapper for sqlite
def dict_factory(cursor, row):
	d = {}
	for idx, col in enumerate(cursor.description):
		if type(row[idx]) == str:
			d[col[0].split('.')[-1]] = row[idx].replace('\\n','\n')
		else:
			d[col[0].split('.')[-1]] = row[idx]
	return d

def query(operation, *params):
	if config['DB_ENGINE'] == 'mysql':
		if 'db' not in g or not g.db.is_connected():
			g.db = mysql.connector.connect(user=config['MYSQL_USER'], password=config['MYSQL_PASSWD'], host=config['MYSQL_HOST'], database=config['MYSQL_DB'])
		cur = g.db.cursor(dictionary=True)
		cur.execute(operation.replace('?', '%s'), params)
		return cur.fetchall()
	elif config['DB_ENGINE'] == 'sqlite':
		if 'db' not in g or not g.db.is_connected():
			g.db = sqlite3.connect(config['SQLITE_DB'])
			g.db.row_factory = dict_factory
		cur = g.db.cursor()
		cur.execute(operation, params)
		return cur.fetchall()

@app.route('/')
def index():
	return render_template('index.html', latestvideos=query('''
				SELECT lectures.*, max(videos.time_updated) AS lastvidtime, courses.short, courses.downloadable, courses.title AS coursetitle
				FROM lectures
				LEFT JOIN videos ON (videos.lecture_id = lectures.id)
				LEFT JOIN courses on (courses.id = lectures.course_id)
				WHERE (? OR (courses.visible AND courses.listed AND lectures.visible AND videos.visible))
				GROUP BY videos.lecture_id
				ORDER BY lastvidtime DESC
				LIMIT 5
			''', False))

@app.route('/videos')
def videos():
	return render_template('videos.html')

@app.route('/faq')
def faq():
	return render_template('faq.html')

@app.route('/play')
def play():
	return render_template('play.html',  active_page='play')

if __name__ == '__main__':
	app.run()
